#!/usr/local/bin/tclsh

# *** If the tclsh binary location variable is not well tuned, please use the    ***
# *** syntax tclsh concat_html.tcl                                               ***

# ..................................................................

proc Usage { } {

 puts "\n---------------------------------------------------------------------------"
 puts "PROGRAM: concat_html.tcl"
 puts "PLATFORM: Unix"
 puts "TYPE: Tcl8.x script"
 puts ""
 puts "AUTHOR: Gerard SOOKAHET"
 puts "DATE: 2000, May 12th"
 puts "VERSION: 0.1"
 puts "---------------------------------------------------------------------------"
 puts ""
 puts "GOAL : reads a set of html files and concatenates them in one"
 puts "big file, with the line <!--NewPage--> at the beginning of each."
 puts ""
 puts "SPECIFS : the user has to provide in the command line the path directory"
 puts "          where are the html files, and the name (with a path) of the" 
 puts "          big file generated by the concatenation."
 puts "          The files will be concatenated in the order they are listed"
 puts "          in the directory ; optionnaly, the user can provide as a third"
 puts "          argument the name (with a path) of a file containing the list"
 puts "          of html files in the order he wishes them to be concatenated."
 puts "          the html files can have indifferently .htm or .html extensions."
 puts ""
 puts "COMMAND LINE :"  
 puts "There's two way to use it"
 puts "1)"
 puts " tclsh concat_html.tcl <pathname> <bigfilename> \[<listfilename>\]"
 puts " Or"
 puts " concat_html.tcl <pathname> <bigfilename> \[<listfilename>\]"
 puts ""
 puts " <pathname> : the path directory where are the html files"
 puts " <bigfilename> : the name (with a path if needed) of the output file"
 puts "OPTIONNAL : <listfilename> : the name (with a path if needed) of a" 
 puts "            text file containing the names  (one file name per line," 
 puts "            without their path) of the html files to be concatenated."
 puts "            They will be  concatenated in this order."
 puts ""
 puts "2)" 
 puts " tclsh concat_html.tcl -files <bigfilename> file1.html file2.html file3.html .... "
 puts " Or"
 puts " concat_html.tcl -files <bigfilename> file1.html file2.html file3.html .... "
 puts "" 
 puts "With the switch -files you can concatenate a list of files in <bigfilename> on" 
 puts "your present working directory."
 puts ""
 puts "NB: If needed Tcl interpreter is available at:"
 puts "    ftp://ftp.lip6.fr/pub/lang/tcl/distrib"
 puts "---------------------------------------------------------------------------"

 exit
}

# ..................................................................

proc ConcatHtml { bigfile addstring list } {

 set f1 [open $bigfile w 0600]
    foreach i $list {
           if [file exists $i] then {
              set f2 [open $i "r"]
                 set ldf [read $f2 [file size $i]]
              close $f2
              puts $f1 $addstring
              puts $f1 $ldf
           } else { puts "WARNING: file $i doesn't exist (skipped)" }
    }

 flush $f1
 close $f1
 exit
}

# ..................................................................

set addstring "<!--NewPage-->"   

if {$argc == 0} then { 
    puts "ERROR : no argument given."
    puts "STOP"
    Usage
} elseif {$argc == 1} then {
    puts "ERROR : too few arguments. Needs at least two.\n"
    puts "STOP"
    Usage
} elseif {$argc == 2} then {
    set pathname [lindex $argv 0]
    set bigfile  [lindex $argv 1]
} elseif {$argc == 3} then {
    set pathname [lindex $argv 0]
    set bigfile  [lindex $argv 1]
    set filesoffiles [lindex $argv 2]
} elseif {$argc >= 4} then {
    set list ""
    set bigfile [lindex $argv 1]

    if {[lindex $argv 0] == "-files"} then {
       foreach i [lrange $argv 2 end] {
              set list [linsert $list end $i]
       }
       ConcatHtml $bigfile $addstring $list 
    } else {
      puts "ERROR : too many errors\n"
      puts "STOP"
      Usage
    }
}

# ..................................................................

if {$argc == 2} then {
   set files [glob -nocomplain $pathname/*.htm*]
   if {$files == ""} then {
      puts "ERROR: there is no html files in $pathname directory\n"
      puts "STOP"
      Usage
   }
} elseif {$argc == 3} then {
   if [file exists $filesoffiles] then {
      set f [open $filesoffiles "r"]
         set ldf [read $f [file size $filesoffiles]]
      close $f
      set files [split $ldf "\n"]
   } else {
      puts "ERROR: file $filesoffiles doesn't exist\n"   
      puts "STOP"
      Usage
   }
}

# ..................................................................

set list ""
foreach i $files {
       set fi $i
       if {$argc == 3} then { set fi "$pathname/$i" }
       set list [linsert $list end $fi]
}

ConcatHtml $bigfile $addstring $list 
exit

# This is the end my friends


